<?php
// public_events_analytics.php - Публичная аналитика событий и ставок для пользователей

error_reporting(E_ALL);
ini_set('display_errors', 1);

// Подключаем конфигурацию
$CONFIG = [
    'DB_HOST' => 'localhost',
    'DB_NAME' => 'stavka',
    'DB_USER' => 'stavka_usr',
    'DB_PASS' => 'a3vhGiC98aj3U1hP'
];

// Подключение к базе данных
try {
    $dsn = "mysql:host={$CONFIG['DB_HOST']};dbname={$CONFIG['DB_NAME']};charset=utf8mb4";
    $pdo = new PDO($dsn, $CONFIG['DB_USER'], $CONFIG['DB_PASS'], [
        PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION,
        PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC,
        PDO::ATTR_EMULATE_PREPARES => false
    ]);
} catch (PDOException $e) {
    die("Ошибка подключения к базе данных: " . $e->getMessage());
}

// Функция получения всех событий с подробной информацией
function getAllEventsDetailed($pdo, $status_filter = null, $league_filter = null, $limit = 50) {
    try {
        $where_conditions = ["1=1"];
        $params = [];
        
        if ($status_filter && $status_filter !== 'all') {
            $where_conditions[] = "e.status = ?";
            $params[] = $status_filter;
        }
        
        if ($league_filter && $league_filter !== 'all') {
            $where_conditions[] = "e.league = ?";
            $params[] = $league_filter;
        }
        
        $where_clause = implode(' AND ', $where_conditions);
        
        $stmt = $pdo->prepare("
            SELECT 
                e.*,
                COUNT(DISTINCT b.user_id) as unique_bettors,
                COUNT(b.bet_id) as total_bets,
                COUNT(CASE WHEN b.status = 'won' THEN 1 END) as winning_bets,
                COUNT(CASE WHEN b.status = 'lost' THEN 1 END) as losing_bets,
                COUNT(CASE WHEN b.status = 'pending' THEN 1 END) as pending_bets,
                GROUP_CONCAT(DISTINCT b.bet_type) as bet_types_used,
                SUM(CASE WHEN b.status = 'won' THEN b.points_earned ELSE 0 END) as total_points_won
            FROM events e
            LEFT JOIN bets b ON e.event_id = b.event_id
            WHERE {$where_clause}
            GROUP BY e.event_id
            ORDER BY 
                CASE e.status 
                    WHEN 'live' THEN 1
                    WHEN 'upcoming' THEN 2
                    WHEN 'finished' THEN 3
                    WHEN 'cancelled' THEN 4
                END,
                e.event_date DESC
            LIMIT ?
        ");
        
        $params[] = $limit;
        $stmt->execute($params);
        return $stmt->fetchAll();
        
    } catch (Exception $e) {
        error_log("getAllEventsDetailed error: " . $e->getMessage());
        return [];
    }
}

// Функция получения полной аналитики по ставкам для события (без приватных данных)
function getEventBetsAnalytics($pdo, $event_id) {
    try {
        $stmt = $pdo->prepare("
            SELECT 
                b.bet_type,
                b.bet_answer,
                b.potential_win,
                b.points_earned,
                b.status,
                b.created_at,
                u.first_name
            FROM bets b
            LEFT JOIN users u ON b.user_id = u.user_id
            WHERE b.event_id = ?
            ORDER BY b.bet_type, b.created_at ASC
        ");
        $stmt->execute([$event_id]);
        return $stmt->fetchAll();
    } catch (Exception $e) {
        return [];
    }
}

// Функция анализа всех возможных исходов ставок (публичная версия)
function analyzePossibleOutcomes($event, $event_bets) {
    if ($event['status'] !== 'finished' || !$event['result']) {
        return null;
    }
    
    $result = json_decode($event['result'], true);
    if (!$result) return null;
    
    // Группируем ставки по типам
    $bet_analysis = [];
    $bet_types_info = [
        'winner' => [
            'name' => '🏆 Победитель',
            'options' => [
                'team1' => "П1 ({$event['team1']})",
                'team2' => "П2 ({$event['team2']})",
                'draw' => 'Ничья'
            ]
        ],
        'exact_score' => [
            'name' => '⚽ Точный счет',
            'options' => []
        ],
        'first_goal' => [
            'name' => '🥅 Первый гол',
            'options' => [
                'team1' => "Первый гол - {$event['team1']}",
                'team2' => "Первый гол - {$event['team2']}"
            ]
        ],
        'total_goals' => [
            'name' => '📊 Тотал голов',
            'options' => [
                'over' => 'Больше 4.5 голов',
                'under' => 'Меньше 4.5 голов'
            ]
        ],
        'red_card' => [
            'name' => '🟥 Удаление',
            'options' => [
                'yes' => 'Будет удаление'
            ]
        ],
        'penalty' => [
            'name' => '🎯 Пенальти',
            'options' => [
                'yes' => 'Будет пенальти'
            ]
        ],
        'own_goal' => [
            'name' => '🤦 Автогол',
            'options' => [
                'yes' => 'Будет автогол'
            ]
        ],
        'corners_winner' => [
            'name' => '📐 Угловые',
            'options' => [
                'team1' => "Больше угловых - {$event['team1']}",
                'team2' => "Больше угловых - {$event['team2']}",
                'draw' => 'Равное количество угловых'
            ]
        ]
    ];
    
    // Инициализируем анализ
    foreach ($bet_types_info as $type => $info) {
        $bet_analysis[$type] = [
            'name' => $info['name'],
            'total_bets' => 0,
            'options' => []
        ];
        
        foreach ($info['options'] as $option => $description) {
            $bet_analysis[$type]['options'][$option] = [
                'description' => $description,
                'bet_count' => 0,
                'won' => false,
                'bettors_count' => 0,
                'total_potential_win' => 0,
                'total_actual_win' => 0
            ];
        }
    }
    
    // Обрабатываем точные счета отдельно
    $exact_scores = [];
    foreach ($event_bets as $bet) {
        if ($bet['bet_type'] === 'exact_score' && $bet['bet_answer'] !== 'other') {
            $exact_scores[] = $bet['bet_answer'];
        }
    }
    $exact_scores = array_unique($exact_scores);
    
    foreach ($exact_scores as $score) {
        $bet_analysis['exact_score']['options'][$score] = [
            'description' => "Счет {$score}",
            'bet_count' => 0,
            'won' => false,
            'bettors_count' => 0,
            'total_potential_win' => 0,
            'total_actual_win' => 0
        ];
    }
    
    // Добавляем "другой счет"
    $bet_analysis['exact_score']['options']['other'] = [
        'description' => 'Другой счет',
        'bet_count' => 0,
        'won' => false,
        'bettors_count' => 0,
        'total_potential_win' => 0,
        'total_actual_win' => 0
    ];
    
    // Заполняем данными из ставок (без персональной информации)
    foreach ($event_bets as $bet) {
        $type = $bet['bet_type'];
        $answer = $bet['bet_answer'];
        
        if (!isset($bet_analysis[$type])) continue;
        if (!isset($bet_analysis[$type]['options'][$answer])) continue;
        
        $bet_analysis[$type]['total_bets']++;
        $bet_analysis[$type]['options'][$answer]['bet_count']++;
        $bet_analysis[$type]['options'][$answer]['bettors_count']++;
        $bet_analysis[$type]['options'][$answer]['total_potential_win'] += $bet['potential_win'];
        if ($bet['status'] === 'won') {
            $bet_analysis[$type]['options'][$answer]['total_actual_win'] += $bet['points_earned'];
        }
    }
    
    // Определяем какие ставки выиграли
    if (isset($result['winner'])) {
        $winning_option = $result['winner'];
        if (isset($bet_analysis['winner']['options'][$winning_option])) {
            $bet_analysis['winner']['options'][$winning_option]['won'] = true;
        }
    }
    
    if (isset($result['score'])) {
        $actual_score = $result['score'];
        if (isset($bet_analysis['exact_score']['options'][$actual_score])) {
            $bet_analysis['exact_score']['options'][$actual_score]['won'] = true;
        } else {
            $bet_analysis['exact_score']['options']['other']['won'] = true;
        }
    }
    
    if (isset($result['first_goal'])) {
        $bet_analysis['first_goal']['options'][$result['first_goal']]['won'] = true;
    }
    
    if (isset($result['total_goals'])) {
        $total = (int)$result['total_goals'];
        if ($total > 4) {
            $bet_analysis['total_goals']['options']['over']['won'] = true;
        } else {
            $bet_analysis['total_goals']['options']['under']['won'] = true;
        }
    }
    
    if ($result['red_card'] ?? false) {
        $bet_analysis['red_card']['options']['yes']['won'] = true;
    }
    
    if ($result['penalty'] ?? false) {
        $bet_analysis['penalty']['options']['yes']['won'] = true;
    }
    
    if ($result['own_goal'] ?? false) {
        $bet_analysis['own_goal']['options']['yes']['won'] = true;
    }
    
    if (isset($result['corners_winner'])) {
        $bet_analysis['corners_winner']['options'][$result['corners_winner']]['won'] = true;
    }
    
    return $bet_analysis;
}

// Функция получения списка лиг
function getLeagues($pdo) {
    try {
        $stmt = $pdo->query("
            SELECT DISTINCT COALESCE(league, 'Без лиги') as league,
                   COUNT(*) as events_count
            FROM events 
            GROUP BY COALESCE(league, 'Без лиги')
            ORDER BY events_count DESC, league ASC
        ");
        return $stmt->fetchAll();
    } catch (Exception $e) {
        return [];
    }
}

// Получение параметров
$status_filter = $_GET['status'] ?? 'all';
$league_filter = $_GET['league'] ?? 'all';
$selected_event = $_GET['event_id'] ?? null;

// Получение данных
$events = getAllEventsDetailed($pdo, $status_filter, $league_filter);
$leagues = getLeagues($pdo);

// Статистика
$total_events = count($events);
$finished_events = count(array_filter($events, fn($e) => $e['status'] === 'finished'));
$upcoming_events = count(array_filter($events, fn($e) => $e['status'] === 'upcoming'));
$live_events = count(array_filter($events, fn($e) => $e['status'] === 'live'));
$total_bets = array_sum(array_column($events, 'total_bets'));
$total_winnings = array_sum(array_column($events, 'total_points_won'));

// Детали выбранного события
$event_details = null;
$event_bets = [];
$bet_analytics = null;
if ($selected_event) {
    $event_details = array_filter($events, fn($e) => $e['event_id'] == $selected_event);
    $event_details = reset($event_details);
    if ($event_details) {
        $event_bets = getEventBetsAnalytics($pdo, $selected_event);
        $bet_analytics = analyzePossibleOutcomes($event_details, $event_bets);
    }
}
?>

<!DOCTYPE html>
<html lang="ru">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Аналитика событий и ставок - Спортивный портал</title>
    <style>
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }
        
        body {
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
            line-height: 1.6;
            color: #333;
            background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
            min-height: 100vh;
            padding: 20px;
        }
        
        .container {
            max-width: 1800px;
            margin: 0 auto;
            background: white;
            border-radius: 15px;
            box-shadow: 0 10px 30px rgba(0,0,0,0.2);
            overflow: hidden;
        }
        
        .header {
            background: linear-gradient(45deg, #FF416C, #FF4B2B);
            color: white;
            padding: 30px;
            text-align: center;
        }
        
        .header h1 {
            font-size: 2.5em;
            margin-bottom: 10px;
            text-shadow: 2px 2px 4px rgba(0,0,0,0.3);
        }
        
        .header p {
            font-size: 1.2em;
            opacity: 0.9;
        }
        
        .nav-links {
            text-align: center;
            margin: 20px 0;
        }
        
        .nav-links a {
            color: white;
            text-decoration: none;
            margin: 0 15px;
            padding: 8px 16px;
            border: 2px solid rgba(255,255,255,0.3);
            border-radius: 20px;
            transition: all 0.3s;
        }
        
        .nav-links a:hover {
            background: rgba(255,255,255,0.2);
            transform: translateY(-2px);
        }
        
        .content {
            padding: 30px;
        }
        
        .stats-overview {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(200px, 1fr));
            gap: 20px;
            margin-bottom: 30px;
        }
        
        .stat-card {
            background: linear-gradient(45deg, #667eea, #764ba2);
            color: white;
            padding: 20px;
            border-radius: 10px;
            text-align: center;
            transform: translateY(0);
            transition: transform 0.3s ease;
        }
        
        .stat-card:hover {
            transform: translateY(-5px);
        }
        
        .stat-number {
            font-size: 2em;
            font-weight: bold;
            margin-bottom: 5px;
        }
        
        .filters {
            background: #f8f9fa;
            padding: 20px;
            border-radius: 10px;
            margin-bottom: 30px;
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(250px, 1fr));
            gap: 20px;
            align-items: end;
        }
        
        .filter-group {
            display: flex;
            flex-direction: column;
        }
        
        .filter-group label {
            font-weight: bold;
            margin-bottom: 8px;
            color: #333;
        }
        
        .filter-group select {
            padding: 12px;
            border: 2px solid #ddd;
            border-radius: 8px;
            font-size: 14px;
            transition: border-color 0.3s;
            background: white;
        }
        
        .filter-group select:focus {
            outline: none;
            border-color: #FF416C;
        }
        
        .events-table {
            width: 100%;
            border-collapse: collapse;
            background: white;
            border-radius: 10px;
            overflow: hidden;
            box-shadow: 0 4px 6px rgba(0,0,0,0.1);
            margin-bottom: 30px;
        }
        
        .events-table th,
        .events-table td {
            padding: 15px 12px;
            text-align: left;
            border-bottom: 1px solid #eee;
        }
        
        .events-table th {
            background: linear-gradient(45deg, #667eea, #764ba2);
            color: white;
            font-weight: bold;
            position: sticky;
            top: 0;
            z-index: 10;
        }
        
        .events-table tr:hover {
            background: #f8f9fa;
            transform: scale(1.01);
            transition: all 0.2s ease;
        }
        
        .event-row {
            cursor: pointer;
        }
        
        .status-badge {
            padding: 6px 12px;
            border-radius: 15px;
            font-size: 0.85em;
            font-weight: bold;
            text-align: center;
            display: inline-block;
            min-width: 90px;
        }
        
        .status-upcoming { background: #ffc107; color: #000; }
        .status-live { 
            background: #dc3545; 
            color: #fff; 
            animation: pulse 2s infinite;
            box-shadow: 0 0 10px rgba(220, 53, 69, 0.5);
        }
        .status-finished { background: #28a745; color: #fff; }
        .status-cancelled { background: #6c757d; color: #fff; }
        
        @keyframes pulse {
            0% { opacity: 1; }
            50% { opacity: 0.7; }
            100% { opacity: 1; }
        }
        
        .result-display {
            font-weight: bold;
            padding: 8px 12px;
            border-radius: 8px;
            background: linear-gradient(45deg, #e9ecef, #f8f9fa);
            box-shadow: 0 2px 4px rgba(0,0,0,0.1);
        }
        
        .bets-summary {
            text-align: center;
        }
        
        .bet-stat {
            display: inline-block;
            margin: 2px 3px;
            padding: 4px 8px;
            border-radius: 6px;
            font-size: 0.8em;
            font-weight: bold;
        }
        
        .bet-won { background: #d4edda; color: #155724; }
        .bet-lost { background: #f8d7da; color: #721c24; }
        .bet-pending { background: #fff3cd; color: #856404; }
        
        .event-details {
            background: white;
            border-radius: 10px;
            padding: 30px;
            margin-bottom: 20px;
            box-shadow: 0 6px 12px rgba(0,0,0,0.1);
        }
        
        .back-button {
            display: inline-block;
            padding: 12px 24px;
            background: linear-gradient(45deg, #FF416C, #FF4B2B);
            color: white;
            text-decoration: none;
            border-radius: 25px;
            font-weight: bold;
            margin-bottom: 25px;
            transition: all 0.3s;
            box-shadow: 0 4px 8px rgba(255, 65, 108, 0.3);
        }
        
        .back-button:hover {
            transform: translateY(-2px);
            box-shadow: 0 6px 12px rgba(255, 65, 108, 0.4);
        }
        
        .analytics-grid {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(400px, 1fr));
            gap: 25px;
            margin-top: 30px;
        }
        
        .bet-type-analysis {
            background: #f8f9fa;
            border-radius: 12px;
            padding: 25px;
            border: 2px solid #dee2e6;
            transition: transform 0.3s ease;
        }
        
        .bet-type-analysis:hover {
            transform: translateY(-3px);
            box-shadow: 0 8px 16px rgba(0,0,0,0.1);
        }
        
        .bet-type-title {
            font-size: 1.3em;
            font-weight: bold;
            margin-bottom: 20px;
            color: #333;
            border-bottom: 3px solid #FF416C;
            padding-bottom: 8px;
        }
        
        .bet-option {
            margin-bottom: 18px;
            padding: 15px;
            border-radius: 10px;
            border: 2px solid #dee2e6;
            background: white;
            transition: all 0.3s ease;
        }
        
        .bet-option:hover {
            transform: translateX(5px);
        }
        
        .bet-option.winning {
            border-color: #28a745;
            background: linear-gradient(45deg, #d4edda, #c3e6cb);
            box-shadow: 0 4px 8px rgba(40, 167, 69, 0.2);
        }
        
        .bet-option.losing {
            border-color: #6c757d;
            background: #f8f9fa;
        }
        
        .bet-option-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 10px;
        }
        
        .bet-option-title {
            font-weight: bold;
            color: #333;
            font-size: 1.1em;
        }
        
        .bet-option.winning .bet-option-title {
            color: #155724;
        }
        
        .bet-result-badge {
            padding: 6px 12px;
            border-radius: 15px;
            font-size: 0.8em;
            font-weight: bold;
        }
        
        .result-won {
            background: #28a745;
            color: white;
            box-shadow: 0 2px 4px rgba(40, 167, 69, 0.3);
        }
        
        .result-lost {
            background: #6c757d;
            color: white;
        }
        
        .bet-stats {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(120px, 1fr));
            gap: 12px;
            margin: 15px 0;
            font-size: 0.9em;
        }
        
        .bet-stat-item {
            text-align: center;
            padding: 12px;
            background: rgba(255,255,255,0.9);
            border-radius: 8px;
            border: 1px solid #e9ecef;
        }
        
        .bet-stat-value {
            font-weight: bold;
            font-size: 1.2em;
            color: #333;
        }
        
        .bet-stat-label {
            color: #666;
            font-size: 0.85em;
            margin-top: 4px;
        }
        
        .popularity-indicator {
            margin-top: 12px;
            font-size: 0.9em;
            color: #666;
            text-align: center;
        }
        
        .no-data {
            text-align: center;
            padding: 60px;
            color: #666;
            background: #f8f9fa;
            border-radius: 10px;
            margin: 30px 0;
        }
        
        .summary-stats {
            background: linear-gradient(45deg, #667eea, #764ba2);
            color: white;
            padding: 25px;
            border-radius: 12px;
            margin: 25px 0;
            text-align: center;
        }
        
        .summary-stats h3 {
            margin-bottom: 20px;
            font-size: 1.4em;
        }
        
        .summary-grid {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(150px, 1fr));
            gap: 20px;
            margin-top: 20px;
        }
        
        .summary-item {
            background: rgba(255,255,255,0.15);
            padding: 18px;
            border-radius: 10px;
            backdrop-filter: blur(10px);
        }
        
        .summary-value {
            font-size: 1.6em;
            font-weight: bold;
            margin-bottom: 8px;
        }
        
        @media (max-width: 1024px) {
            .analytics-grid {
                grid-template-columns: 1fr;
            }
            
            .events-table {
                font-size: 0.9em;
            }
            
            .events-table th,
            .events-table td {
                padding: 10px 8px;
            }
        }
        
        @media (max-width: 768px) {
            .filters {
                grid-template-columns: 1fr;
            }
            
            .stats-overview {
                grid-template-columns: repeat(2, 1fr);
            }
            
            .bet-stats {
                grid-template-columns: repeat(2, 1fr);
            }
            
            .header h1 {
                font-size: 2em;
            }
            
            .content {
                padding: 20px;
            }
        }
        
        .info-tooltip {
            background: #007bff;
            color: white;
            padding: 4px 8px;
            border-radius: 10px;
            font-size: 0.7em;
            margin-left: 8px;
            cursor: help;
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="header">
            <h1>📊 Аналитика событий и ставок</h1>
            <p>Детальная статистика матчей, результатов и популярности исходов</p>
            
            <div class="nav-links">
                <a href="teams_table_page.php">🏆 Турнирная таблица</a>
                <a href="/">🏠 Главная</a>
                <a href="/bot">🤖 Телеграм бот</a>
            </div>
        </div>
        
        <div class="content">
            <?php if ($selected_event && $event_details): ?>
                <!-- Детальная аналитика выбранного события -->
                <a href="?" class="back-button">🔙 Назад к списку событий</a>
                
                <div class="event-details">
                    <h2>🏟 Детальная аналитика матча</h2>
                    
                    <div style="display: grid; grid-template-columns: repeat(auto-fit, minmax(300px, 1fr)); gap: 25px; margin: 25px 0;">
                        <div>
                            <h3>📋 Информация о матче</h3>
                            <p><strong>Название:</strong> <?= htmlspecialchars($event_details['title']) ?></p>
                            <p><strong>Команды:</strong> <?= htmlspecialchars($event_details['team1']) ?> vs <?= htmlspecialchars($event_details['team2']) ?></p>
                            <p><strong>Дата:</strong> <?= date('d.m.Y H:i', strtotime($event_details['event_date'])) ?></p>
                            <p><strong>Лига:</strong> <?= htmlspecialchars($event_details['league'] ?: 'Без лиги') ?></p>
                            <p><strong>Статус:</strong> <span class="status-badge status-<?= $event_details['status'] ?>"><?= ucfirst($event_details['status']) ?></span></p>
                        </div>
                        
                        <div>
                            <h3>📊 Статистика ставок</h3>
                            <p><strong>Всего ставок:</strong> <?= $event_details['total_bets'] ?></p>
                            <p><strong>Участников:</strong> <?= $event_details['unique_bettors'] ?> игроков</p>
                            <p><strong>Выигрышных ставок:</strong> <span class="bet-won"><?= $event_details['winning_bets'] ?></span></p>
                            <p><strong>Проигрышных ставок:</strong> <span class="bet-lost"><?= $event_details['losing_bets'] ?></span></p>
                            <p><strong>Ожидающих:</strong> <span class="bet-pending"><?= $event_details['pending_bets'] ?></span></p>
                            <p><strong>Процент успеха:</strong> 
                                <?= $event_details['total_bets'] > 0 ? round(($event_details['winning_bets'] / $event_details['total_bets']) * 100, 1) : 0 ?>%
                            </p>
                        </div>
                        
                        <?php if ($event_details['status'] === 'finished' && $event_details['result']): ?>
                            <?php $result = json_decode($event_details['result'], true); ?>
                            <div>
                                <h3>🏆 Результаты матча</h3>
                                <p><strong>Итоговый счет:</strong> <?= htmlspecialchars($result['score'] ?? 'Н/Д') ?></p>
                                <p><strong>Победитель:</strong> 
                                    <?php
                                    switch ($result['winner'] ?? '') {
                                        case 'team1': echo htmlspecialchars($event_details['team1']); break;
                                        case 'team2': echo htmlspecialchars($event_details['team2']); break;
                                        case 'draw': echo 'Ничья'; break;
                                        default: echo 'Н/Д';
                                    }
                                    ?>
                                </p>
                                <p><strong>Общий тотал голов:</strong> <?= $result['total_goals'] ?? 'Н/Д' ?></p>
                                
                                <div style="margin-top: 15px;">
                                    <?php if ($result['first_goal'] ?? false): ?>
                                        <p><strong>Первый гол:</strong> 
                                            <?= $result['first_goal'] === 'team1' ? htmlspecialchars($event_details['team1']) : htmlspecialchars($event_details['team2']) ?>
                                        </p>
                                    <?php endif; ?>
                                    
                                    <div style="margin-top: 10px;">
                                        <?php if ($result['red_card'] ?? false): ?>
                                            <span class="bet-stat" style="background: #f8d7da;">🟥 Было удаление</span>
                                        <?php endif; ?>
                                        <?php if ($result['penalty'] ?? false): ?>
                                            <span class="bet-stat" style="background: #fff3cd;">🎯 Был пенальти</span>
                                        <?php endif; ?>
                                        <?php if ($result['own_goal'] ?? false): ?>
                                            <span class="bet-stat" style="background: #e2e3e5;">🤦 Был автогол</span>
                                        <?php endif; ?>
                                        <?php if (isset($result['corners_winner'])): ?>
                                            <span class="bet-stat" style="background: #d1ecf1;">📐 Угловые: 
                                                <?php
                                                switch ($result['corners_winner']) {
                                                    case 'team1': echo htmlspecialchars($event_details['team1']); break;
                                                    case 'team2': echo htmlspecialchars($event_details['team2']); break;
                                                    case 'draw': echo 'поровну'; break;
                                                }
                                                ?>
                                            </span>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                    
                    <!-- Общая статистика по событию -->
                    <?php if ($event_details['status'] === 'finished'): ?>
                        <div class="summary-stats">
                            <h3>📈 Сводка по матчу</h3>
                            <div class="summary-grid">
                                <div class="summary-item">
                                    <div class="summary-value"><?= $event_details['total_bets'] ?></div>
                                    <div>Всего прогнозов</div>
                                </div>
                                <div class="summary-item">
                                    <div class="summary-value"><?= $event_details['unique_bettors'] ?></div>
                                    <div>Участников</div>
                                </div>
                                <div class="summary-item">
                                    <div class="summary-value">
                                        <?= $event_details['total_bets'] > 0 ? round(($event_details['winning_bets'] / $event_details['total_bets']) * 100, 1) : 0 ?>%
                                    </div>
                                    <div>Успешных прогнозов</div>
                                </div>
                                <div class="summary-item">
                                    <div class="summary-value">+<?= $event_details['total_points_won'] ?></div>
                                    <div>Баллов выиграно</div>
                                </div>
                                <div class="summary-item">
                                    <div class="summary-value"><?= count(array_unique(explode(',', $event_details['bet_types_used'] ?: ''))) ?></div>
                                    <div>Типов ставок</div>
                                </div>
                            </div>
                        </div>
                    <?php endif; ?>
                    
                    <!-- Детальная аналитика по типам ставок -->
                    <?php if ($bet_analytics): ?>
                        <h3 style="margin-top: 30px;">🎯 Анализ популярности исходов</h3>
                        <p style="color: #666; margin-bottom: 25px;">
                            Показано какие исходы "сыграли" ✅ и какие нет ❌, с информацией о популярности среди игроков
                            <span class="info-tooltip" title="Данные показывают только общую статистику без персональной информации">ℹ️</span>
                        </p>
                        
                        <div class="analytics-grid">
                            <?php foreach ($bet_analytics as $bet_type => $type_data): ?>
                                <?php if ($type_data['total_bets'] > 0): ?>
                                    <div class="bet-type-analysis">
                                        <div class="bet-type-title">
                                            <?= $type_data['name'] ?> 
                                            <span style="font-size: 0.8em; color: #666;">(<?= $type_data['total_bets'] ?> прогнозов)</span>
                                        </div>
                                        
                                        <?php foreach ($type_data['options'] as $option => $option_data): ?>
                                            <?php if ($option_data['bet_count'] > 0): ?>
                                                <div class="bet-option <?= $option_data['won'] ? 'winning' : 'losing' ?>">
                                                    <div class="bet-option-header">
                                                        <div class="bet-option-title">
                                                            <?= htmlspecialchars($option_data['description']) ?>
                                                        </div>
                                                        <div class="bet-result-badge <?= $option_data['won'] ? 'result-won' : 'result-lost' ?>">
                                                            <?= $option_data['won'] ? '✅ СЫГРАЛ' : '❌ НЕ СЫГРАЛ' ?>
                                                        </div>
                                                    </div>
                                                    
                                                    <div class="bet-stats">
                                                        <div class="bet-stat-item">
                                                            <div class="bet-stat-value"><?= $option_data['bet_count'] ?></div>
                                                            <div class="bet-stat-label">Прогнозов</div>
                                                        </div>
                                                        <div class="bet-stat-item">
                                                            <div class="bet-stat-value">
                                                                <?= $type_data['total_bets'] > 0 ? round(($option_data['bet_count'] / $type_data['total_bets']) * 100, 1) : 0 ?>%
                                                            </div>
                                                            <div class="bet-stat-label">Популярность</div>
                                                        </div>
                                                        <div class="bet-stat-item">
                                                            <div class="bet-stat-value"><?= $option_data['total_potential_win'] ?></div>
                                                            <div class="bet-stat-label">Потенциал</div>
                                                        </div>
                                                        <div class="bet-stat-item">
                                                            <div class="bet-stat-value">
                                                                <?= $option_data['won'] ? "+{$option_data['total_actual_win']}" : "0" ?>
                                                            </div>
                                                            <div class="bet-stat-label">Выплачено</div>
                                                        </div>
                                                    </div>
                                                    
                                                    <div class="popularity-indicator">
                                                        <strong>Популярность:</strong> 
                                                        <?php 
                                                        $popularity = $type_data['total_bets'] > 0 ? round(($option_data['bet_count'] / $type_data['total_bets']) * 100, 1) : 0;
                                                        if ($popularity >= 50) echo "🔥 Очень популярный выбор";
                                                        elseif ($popularity >= 25) echo "👍 Популярный выбор";
                                                        elseif ($popularity >= 10) echo "📊 Средняя популярность";
                                                        else echo "🤔 Редкий выбор";
                                                        ?>
                                                        (<?= $option_data['bettors_count'] ?> участников)
                                                    </div>
                                                </div>
                                            <?php endif; ?>
                                        <?php endforeach; ?>
                                        
                                        <?php
                                        // Показываем варианты без ставок для завершенных событий
                                        $no_bet_options = array_filter($type_data['options'], fn($opt) => $opt['bet_count'] == 0);
                                        if (!empty($no_bet_options) && $event_details['status'] === 'finished'):
                                        ?>
                                            <div style="margin-top: 20px; padding-top: 15px; border-top: 1px solid #dee2e6;">
                                                <div style="font-size: 0.9em; color: #666; margin-bottom: 12px;">
                                                    <strong>Варианты без прогнозов:</strong>
                                                </div>
                                                <?php foreach ($no_bet_options as $option => $option_data): ?>
                                                    <div style="padding: 10px; margin: 6px 0; background: #f8f9fa; border-radius: 8px; display: flex; justify-content: space-between; align-items: center;">
                                                        <span><?= htmlspecialchars($option_data['description']) ?></span>
                                                        <span class="bet-result-badge <?= $option_data['won'] ? 'result-won' : 'result-lost' ?>">
                                                            <?= $option_data['won'] ? '✅ СЫГРАЛ БЫ' : '❌ НЕ СЫГРАЛ БЫ' ?>
                                                        </span>
                                                    </div>
                                                <?php endforeach; ?>
                                            </div>
                                        <?php endif; ?>
                                    </div>
                                <?php endif; ?>
                            <?php endforeach; ?>
                        </div>
                        
                        <!-- Итоговая статистика -->
                        <div style="background: #e9ecef; padding: 25px; border-radius: 12px; margin-top: 35px;">
                            <h4 style="margin-bottom: 20px;">📈 Итоговая статистика по исходам:</h4>
                            <div style="display: grid; grid-template-columns: repeat(auto-fit, minmax(200px, 1fr)); gap: 20px;">
                                <?php
                                $total_winning_options = 0;
                                $total_options_with_bets = 0;
                                foreach ($bet_analytics as $type_data) {
                                    foreach ($type_data['options'] as $option_data) {
                                        if ($option_data['bet_count'] > 0) {
                                            $total_options_with_bets++;
                                            if ($option_data['won']) {
                                                $total_winning_options++;
                                            }
                                        }
                                    }
                                }
                                ?>
                                <div style="text-align: center; background: white; padding: 20px; border-radius: 10px; box-shadow: 0 2px 4px rgba(0,0,0,0.1);">
                                    <div style="font-size: 1.8em; font-weight: bold; color: #28a745;"><?= $total_winning_options ?></div>
                                    <div>Выигрышных исходов</div>
                                </div>
                                <div style="text-align: center; background: white; padding: 20px; border-radius: 10px; box-shadow: 0 2px 4px rgba(0,0,0,0.1);">
                                    <div style="font-size: 1.8em; font-weight: bold; color: #dc3545;"><?= $total_options_with_bets - $total_winning_options ?></div>
                                    <div>Проигрышных исходов</div>
                                </div>
                                <div style="text-align: center; background: white; padding: 20px; border-radius: 10px; box-shadow: 0 2px 4px rgba(0,0,0,0.1);">
                                    <div style="font-size: 1.8em; font-weight: bold; color: #667eea;">
                                        <?= $total_options_with_bets > 0 ? round(($total_winning_options / $total_options_with_bets) * 100, 1) : 0 ?>%
                                    </div>
                                    <div>Процент удачных исходов</div>
                                </div>
                                <div style="text-align: center; background: white; padding: 20px; border-radius: 10px; box-shadow: 0 2px 4px rgba(0,0,0,0.1);">
                                    <div style="font-size: 1.8em; font-weight: bold; color: #FF416C;"><?= count(array_unique(explode(',', $event_details['bet_types_used'] ?: ''))) ?></div>
                                    <div>Типов прогнозов</div>
                                </div>
                            </div>
                        </div>
                    <?php else: ?>
                        <div class="no-data">
                            <h3>📊 Аналитика недоступна</h3>
                            <p>Детальная аналитика доступна только для завершенных матчей</p>
                        </div>
                    <?php endif; ?>
                </div>
                
            <?php else: ?>
                <!-- Общая статистика -->
                <div class="stats-overview">
                    <div class="stat-card">
                        <div class="stat-number"><?= $total_events ?></div>
                        <div>Всего событий</div>
                    </div>
                    <div class="stat-card">
                        <div class="stat-number"><?= $live_events ?></div>
                        <div>Сейчас в эфире</div>
                    </div>
                    <div class="stat-card">
                        <div class="stat-number"><?= $upcoming_events ?></div>
                        <div>Предстоящих</div>
                    </div>
                    <div class="stat-card">
                        <div class="stat-number"><?= $finished_events ?></div>
                        <div>Завершенных</div>
                    </div>
                    <div class="stat-card">
                        <div class="stat-number"><?= $total_bets ?></div>
                        <div>Всего прогнозов</div>
                    </div>
                    <div class="stat-card">
                        <div class="stat-number">+<?= $total_winnings ?></div>
                        <div>Баллов выиграно</div>
                    </div>
                </div>
                
                <!-- Фильтры -->
                <div class="filters">
                    <div class="filter-group">
                        <label for="status">📊 Статус событий:</label>
                        <select id="status" onchange="applyFilters()">
                            <option value="all" <?= $status_filter === 'all' ? 'selected' : '' ?>>Все события</option>
                            <option value="live" <?= $status_filter === 'live' ? 'selected' : '' ?>>🔴 Сейчас в эфире</option>
                            <option value="upcoming" <?= $status_filter === 'upcoming' ? 'selected' : '' ?>>⏳ Предстоящие</option>
                            <option value="finished" <?= $status_filter === 'finished' ? 'selected' : '' ?>>✅ Завершенные</option>
                            <option value="cancelled" <?= $status_filter === 'cancelled' ? 'selected' : '' ?>>🚫 Отмененные</option>
                        </select>
                    </div>
                    
                    <div class="filter-group">
                        <label for="league">🏆 Лига/турнир:</label>
                        <select id="league" onchange="applyFilters()">
                            <option value="all" <?= $league_filter === 'all' ? 'selected' : '' ?>>Все лиги</option>
                            <?php foreach ($leagues as $league): ?>
                                <option value="<?= htmlspecialchars($league['league']) ?>" 
                                        <?= $league_filter === $league['league'] ? 'selected' : '' ?>>
                                    <?= htmlspecialchars($league['league']) ?> (<?= $league['events_count'] ?>)
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                </div>
                
                <?php if (empty($events)): ?>
                    <div class="no-data">
                        <h3>🤷‍♂️ Нет событий для отображения</h3>
                        <p>Попробуйте изменить фильтры или зайдите позже</p>
                        <p>События добавляются администраторами регулярно</p>
                    </div>
                <?php else: ?>
                    <!-- Таблица событий -->
                    <div style="overflow-x: auto;">
                        <table class="events-table">
                            <thead>
                                <tr>
                                    <th>ID</th>
                                    <th>Статус</th>
                                    <th>Дата</th>
                                    <th>Событие</th>
                                    <th>Лига</th>
                                    <th>Результат</th>
                                    <th>Прогнозы</th>
                                    <th>Популярность</th>
                                    <th>🎯 Анализ</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($events as $event): ?>
                                    <tr class="event-row" onclick="showEventDetails(<?= $event['event_id'] ?>)">
                                        <td><strong><?= $event['event_id'] ?></strong></td>
                                        <td>
                                            <span class="status-badge status-<?= $event['status'] ?>">
                                                <?php
                                                $status_names = [
                                                    'upcoming' => '⏳ Предстоящее',
                                                    'live' => '🔴 В эфире',
                                                    'finished' => '✅ Завершено',
                                                    'cancelled' => '�� Отменено'
                                                ];
                                                echo $status_names[$event['status']] ?? $event['status'];
                                                ?>
                                            </span>
                                        </td>
                                        <td>
                                            <strong><?= date('d.m.Y', strtotime($event['event_date'])) ?></strong><br>
                                            <small style="color: #666;"><?= date('H:i', strtotime($event['event_date'])) ?></small>
                                        </td>
                                        <td>
                                            <strong style="color: #333;"><?= htmlspecialchars($event['title']) ?></strong><br>
                                            <span style="color: #666; font-size: 0.9em;">
                                                <?= htmlspecialchars($event['team1']) ?> vs <?= htmlspecialchars($event['team2']) ?>
                                            </span>
                                        </td>
                                        <td style="font-size: 0.9em;"><?= htmlspecialchars($event['league'] ?: 'Без лиги') ?></td>
                                        <td>
                                            <?php if ($event['status'] === 'finished' && $event['result']): ?>
                                                <?php $result = json_decode($event['result'], true); ?>
                                                <div class="result-display">
                                                    <strong style="font-size: 1.1em;"><?= htmlspecialchars($result['score'] ?? 'Н/Д') ?></strong><br>
                                                    <small style="color: #666;">
                                                        Тотал: <?= $result['total_goals'] ?? 'Н/Д' ?><br>
                                                        <?php
                                                        switch ($result['winner'] ?? '') {
                                                            case 'team1': echo htmlspecialchars($event['team1']); break;
                                                            case 'team2': echo htmlspecialchars($event['team2']); break;
                                                            case 'draw': echo 'Ничья'; break;
                                                            default: echo 'Н/Д';
                                                        }
                                                        ?>
                                                    </small>
                                                </div>
                                            <?php else: ?>
                                                <span style="color: #999;">-</span>
                                            <?php endif; ?>
                                        </td>
                                        <td class="bets-summary">
                                            <strong style="font-size: 1.1em;"><?= $event['total_bets'] ?></strong> прогнозов<br>
                                            <?php if ($event['total_bets'] > 0): ?>
                                                <span class="bet-stat bet-won"><?= $event['winning_bets'] ?> ✅</span>
                                                <span class="bet-stat bet-lost"><?= $event['losing_bets'] ?> ❌</span>
                                                <?php if ($event['pending_bets'] > 0): ?>
                                                    <span class="bet-stat bet-pending"><?= $event['pending_bets'] ?> ⏳</span>
                                                <?php endif; ?>
                                                <br><small style="color: #666;"><?= $event['unique_bettors'] ?> участников</small>
                                            <?php endif; ?>
                                        </td>
                                        <td style="text-align: center;">
                                            <?php if ($event['total_bets'] > 0): ?>
                                                <?php 
                                                $popularity_score = min(100, ($event['unique_bettors'] * 10) + ($event['total_bets'] * 2));
                                                $popularity_class = $popularity_score >= 80 ? 'hot' : ($popularity_score >= 40 ? 'warm' : 'cool');
                                                ?>
                                                <div style="font-weight: bold; color: <?= $popularity_score >= 80 ? '#dc3545' : ($popularity_score >= 40 ? '#ffc107' : '#28a745') ?>;">
                                                    <?php if ($popularity_score >= 80): ?>
                                                        🔥 Очень популярное
                                                    <?php elseif ($popularity_score >= 40): ?>
                                                        📈 Популярное
                                                    <?php else: ?>
                                                        📊 Обычное
                                                    <?php endif; ?>
                                                </div>
                                                <small style="color: #666;"><?= $popularity_score ?> баллов</small>
                                            <?php else: ?>
                                                <span style="color: #999;">-</span>
                                            <?php endif; ?>
                                        </td>
                                        <td style="text-align: center;">
                                            <?php if ($event['status'] === 'finished' && $event['total_bets'] > 0): ?>
                                                <span style="background: linear-gradient(45deg, #FF416C, #FF4B2B); color: white; padding: 6px 12px; border-radius: 15px; font-size: 0.8em; font-weight: bold;">
                                                    📊 ДЕТАЛИ
                                                </span>
                                            <?php else: ?>
                                                <span style="color: #999;">-</span>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>
            <?php endif; ?>
        </div>
    </div>

    <script>
        function applyFilters() {
            const status = document.getElementById('status').value;
            const league = document.getElementById('league').value;
            
            const params = new URLSearchParams(window.location.search);
            params.set('status', status);
            params.set('league', league);
            
            window.location.href = '?' + params.toString();
        }
        
        function showEventDetails(eventId) {
            const params = new URLSearchParams(window.location.search);
            params.set('event_id', eventId);
            window.location.href = '?' + params.toString();
        }
        
        // Добавим небольшую анимацию при загрузке
        document.addEventListener('DOMContentLoaded', function() {
            const statCards = document.querySelectorAll('.stat-card');
            statCards.forEach((card, index) => {
                setTimeout(() => {
                    card.style.opacity = '0';
                    card.style.transform = 'translateY(20px)';
                    card.style.transition = 'all 0.5s ease';
                    setTimeout(() => {
                        card.style.opacity = '1';
                        card.style.transform = 'translateY(0)';
                    }, 50);
                }, index * 100);
            });
        });
    </script>
</body>
</html>