<?php
// ========================================
// ФИНАЛЬНОЕ ИСПРАВЛЕНИЕ КОДИРОВКИ
// final_encoding_fix.php
// ========================================

// Устанавливаем правильную кодировку для PHP
mb_internal_encoding('UTF-8');
mb_http_output('UTF-8');
ini_set('default_charset', 'UTF-8');

require_once 'webhook.php';

function finalEncodingFix() {
    global $CONFIG;
    
    echo "🔧 Финальное исправление кодировки...\n\n";
    
    try {
        // Подключаемся с принудительной UTF-8
        $dsn = "mysql:host={$CONFIG['DB_HOST']};dbname={$CONFIG['DB_NAME']};charset=utf8mb4";
        $pdo = new PDO($dsn, $CONFIG['DB_USER'], $CONFIG['DB_PASS'], [
            PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION,
            PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC,
            PDO::MYSQL_ATTR_INIT_COMMAND => "SET NAMES utf8mb4 COLLATE utf8mb4_unicode_ci"
        ]);
        
        echo "✅ Подключение к БД\n";
        
        // Устанавливаем кодировку для сессии
        $pdo->exec("SET NAMES utf8mb4 COLLATE utf8mb4_unicode_ci");
        $pdo->exec("SET CHARACTER SET utf8mb4");
        $pdo->exec("SET character_set_results = utf8mb4");
        $pdo->exec("SET character_set_client = utf8mb4");
        $pdo->exec("SET character_set_connection = utf8mb4");
        
        echo "✅ Кодировка сессии установлена\n";
        
        // Проверяем и исправляем кодировку всех таблиц
        $tables = ['users', 'events', 'bets', 'balance_transactions', 'notifications', 'user_states', 'bet_settings'];
        
        echo "\n🔄 Исправление кодировки таблиц:\n";
        
        foreach ($tables as $table) {
            try {
                // Проверяем текущую кодировку таблицы
                $stmt = $pdo->query("SHOW CREATE TABLE `{$table}`");
                $result = $stmt->fetch();
                $createStatement = $result["Create Table"];
                
                if (strpos($createStatement, 'utf8mb4_unicode_ci') === false) {
                    echo "🔧 {$table}: исправляем кодировку... ";
                    
                    // Конвертируем таблицу в UTF-8
                    $pdo->exec("ALTER TABLE `{$table}` CONVERT TO CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci");
                    echo "✅\n";
                } else {
                    echo "✅ {$table}: кодировка уже правильная\n";
                }
                
            } catch (Exception $e) {
                echo "⚠️  {$table}: ошибка - " . $e->getMessage() . "\n";
            }
        }
        
        // Проверяем кодировку базы данных
        echo "\n🔄 Проверка кодировки базы данных:\n";
        
        $stmt = $pdo->query("SHOW CREATE DATABASE `{$CONFIG['DB_NAME']}`");
        $result = $stmt->fetch();
        $createDB = $result["Create Database"];
        
        if (strpos($createDB, 'utf8mb4') === false) {
            echo "🔧 База данных: исправляем кодировку... ";
            try {
                $pdo->exec("ALTER DATABASE `{$CONFIG['DB_NAME']}` CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci");
                echo "✅\n";
            } catch (Exception $e) {
                echo "⚠️  Ошибка: " . $e->getMessage() . "\n";
            }
        } else {
            echo "✅ База данных: кодировка правильная\n";
        }
        
        // Тестируем отправку сообщения с русским текстом
        echo "\n🧪 Тест отправки русского текста:\n";
        
        if (isset($CONFIG['ADMIN_IDS'][0])) {
            $admin_id = $CONFIG['ADMIN_IDS'][0];
            
            $test_text = "🧪 <b>Тест кодировки</b>\n\n";
            $test_text .= "✅ Русский текст: Привет, мир!\n";
            $test_text .= "✅ Эмодзи: 🎉🚀💰⚽🏆\n";
            $test_text .= "✅ Время: " . date('H:i:s') . "\n\n";
            $test_text .= "Если вы видите этот текст нормально - кодировка исправлена!";
            
            echo "📤 Отправляем тестовое сообщение админу {$admin_id}...\n";
            
            $result = send_message($admin_id, $test_text);
            
            if ($result) {
                echo "✅ Тестовое сообщение отправлено успешно!\n";
                echo "📱 Проверьте Telegram - если текст читается нормально, кодировка исправлена\n";
            } else {
                echo "❌ Ошибка отправки тестового сообщения\n";
            }
        } else {
            echo "⚠️  Нет админов для тестирования\n";
        }
        
        // Финальная проверка статистики
        echo "\n📊 Финальная проверка базы:\n";
        
        $db = SportsDatabase::getInstance();
        $stats = $db->getStatistics();
        
        echo "👥 Пользователей: " . $stats['total_users'] . "\n";
        echo "⚽ События: " . $stats['total_events'] . "\n";
        echo "🎯 Ставки: " . $stats['total_bets'] . "\n";
        echo "⚙️ Настройки ставок: ";
        
        $stmt = $pdo->query("SELECT COUNT(*) as count FROM bet_settings");
        $bet_settings_count = $stmt->fetch()['count'];
        echo $bet_settings_count . "\n";
        
        echo "\n🎉 Исправление кодировки завершено!\n";
        echo "🤖 Бот должен теперь корректно отображать русский текст\n";
        
    } catch (Exception $e) {
        echo "❌ Ошибка: " . $e->getMessage() . "\n";
        exit(1);
    }
}

// Проверка CLI
if (php_sapi_name() !== 'cli') {
    echo "❌ Только из командной строки!\n";
    exit(1);
}

finalEncodingFix();
?>