<?php
// improved_teams_table.php - Информативная турнирная таблица

error_reporting(E_ALL);
ini_set('display_errors', 1);

// Подключаем конфигурацию
$CONFIG = [
    'DB_HOST' => 'localhost',
    'DB_NAME' => 'stavka',
    'DB_USER' => 'stavka_usr',
    'DB_PASS' => 'a3vhGiC98aj3U1hP'
];

// Подключение к базе данных
try {
    $dsn = "mysql:host={$CONFIG['DB_HOST']};dbname={$CONFIG['DB_NAME']};charset=utf8mb4";
    $pdo = new PDO($dsn, $CONFIG['DB_USER'], $CONFIG['DB_PASS'], [
        PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION,
        PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC,
        PDO::ATTR_EMULATE_PREPARES => false
    ]);
} catch (PDOException $e) {
    die("Ошибка подключения к базе данных: " . $e->getMessage());
}

// Функция получения всех событий с подробной информацией
function getAllEventsDetailed($pdo, $status_filter = null, $league_filter = null, $limit = 50) {
    try {
        $where_conditions = ["1=1"];
        $params = [];
        
        if ($status_filter && $status_filter !== 'all') {
            $where_conditions[] = "e.status = ?";
            $params[] = $status_filter;
        }
        
        if ($league_filter && $league_filter !== 'all') {
            $where_conditions[] = "e.league = ?";
            $params[] = $league_filter;
        }
        
        $where_clause = implode(' AND ', $where_conditions);
        
        $stmt = $pdo->prepare("
            SELECT 
                e.*,
                COUNT(DISTINCT b.user_id) as unique_bettors,
                COUNT(b.bet_id) as total_bets,
                COUNT(CASE WHEN b.status = 'won' THEN 1 END) as winning_bets,
                COUNT(CASE WHEN b.status = 'lost' THEN 1 END) as losing_bets,
                COUNT(CASE WHEN b.status = 'pending' THEN 1 END) as pending_bets,
                GROUP_CONCAT(DISTINCT b.bet_type) as bet_types_used
            FROM events e
            LEFT JOIN bets b ON e.event_id = b.event_id
            WHERE {$where_clause}
            GROUP BY e.event_id
            ORDER BY 
                CASE e.status 
                    WHEN 'live' THEN 1
                    WHEN 'upcoming' THEN 2
                    WHEN 'finished' THEN 3
                    WHEN 'cancelled' THEN 4
                END,
                e.event_date DESC
            LIMIT ?
        ");
        
        $params[] = $limit;
        $stmt->execute($params);
        return $stmt->fetchAll();
        
    } catch (Exception $e) {
        error_log("getAllEventsDetailed error: " . $e->getMessage());
        return [];
    }
}

// Функция получения детальной статистики по ставкам для события
function getEventBetsDetails($pdo, $event_id) {
    try {
        $stmt = $pdo->prepare("
            SELECT 
                b.*,
                u.first_name,
                u.username
            FROM bets b
            LEFT JOIN users u ON b.user_id = u.user_id
            WHERE b.event_id = ?
            ORDER BY b.created_at ASC
        ");
        $stmt->execute([$event_id]);
        return $stmt->fetchAll();
    } catch (Exception $e) {
        return [];
    }
}

// Функция форматирования отображения ставки
function formatBetDisplay($bet_type, $bet_answer, $team1, $team2) {
    switch ($bet_type) {
        case 'winner':
            switch ($bet_answer) {
                case 'team1': return "П1 ({$team1})";
                case 'team2': return "П2 ({$team2})";
                case 'draw': return "Ничья";
            }
            break;
        case 'exact_score':
            return $bet_answer === 'other' ? "Другой счет" : "Счет {$bet_answer}";
        case 'first_goal':
            switch ($bet_answer) {
                case 'team1': return "Первый гол - {$team1}";
                case 'team2': return "Первый гол - {$team2}";
            }
            break;
        case 'total_goals':
            return $bet_answer === 'over' ? "Больше 4.5 голов" : "Меньше 4.5 голов";
        case 'red_card':
            return "Будет удаление";
        case 'penalty':
            return "Будет пенальти";
        case 'own_goal':
            return "Будет автогол";
        case 'corners_winner':
            switch ($bet_answer) {
                case 'team1': return "Больше угловых - {$team1}";
                case 'team2': return "Больше угловых - {$team2}";
                case 'draw': return "Равное количество угловых";
            }
            break;
    }
    return $bet_answer;
}

// Функция получения списка лиг
function getLeagues($pdo) {
    try {
        $stmt = $pdo->query("
            SELECT DISTINCT COALESCE(league, 'Без лиги') as league,
                   COUNT(*) as events_count
            FROM events 
            GROUP BY COALESCE(league, 'Без лиги')
            ORDER BY events_count DESC, league ASC
        ");
        return $stmt->fetchAll();
    } catch (Exception $e) {
        return [];
    }
}

// Получение параметров
$status_filter = $_GET['status'] ?? 'all';
$league_filter = $_GET['league'] ?? 'all';
$view_mode = $_GET['view'] ?? 'events';
$selected_event = $_GET['event_id'] ?? null;

// Получение данных
$events = getAllEventsDetailed($pdo, $status_filter, $league_filter);
$leagues = getLeagues($pdo);

// Статистика
$total_events = count($events);
$finished_events = count(array_filter($events, fn($e) => $e['status'] === 'finished'));
$upcoming_events = count(array_filter($events, fn($e) => $e['status'] === 'upcoming'));
$live_events = count(array_filter($events, fn($e) => $e['status'] === 'live'));
$total_bets = array_sum(array_column($events, 'total_bets'));
$unique_bettors = count(array_unique(array_merge(...array_map(fn($e) => [$e['unique_bettors']], $events))));

// Детали выбранного события
$event_details = null;
$event_bets = [];
if ($selected_event) {
    $event_details = array_filter($events, fn($e) => $e['event_id'] == $selected_event);
    $event_details = reset($event_details);
    if ($event_details) {
        $event_bets = getEventBetsDetails($pdo, $selected_event);
    }
}
?>

<!DOCTYPE html>
<html lang="ru">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Детальная информация о событиях и ставках</title>
    <style>
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }
        
        body {
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
            line-height: 1.6;
            color: #333;
            background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
            min-height: 100vh;
            padding: 20px;
        }
        
        .container {
            max-width: 1800px;
            margin: 0 auto;
            background: white;
            border-radius: 15px;
            box-shadow: 0 10px 30px rgba(0,0,0,0.2);
            overflow: hidden;
        }
        
        .header {
            background: linear-gradient(45deg, #FF416C, #FF4B2B);
            color: white;
            padding: 30px;
            text-align: center;
        }
        
        .header h1 {
            font-size: 2.5em;
            margin-bottom: 10px;
            text-shadow: 2px 2px 4px rgba(0,0,0,0.3);
        }
        
        .nav-links {
            text-align: center;
            margin: 20px 0;
        }
        
        .nav-links a {
            color: white;
            text-decoration: none;
            margin: 0 15px;
            padding: 8px 16px;
            border: 2px solid rgba(255,255,255,0.3);
            border-radius: 20px;
            transition: all 0.3s;
        }
        
        .nav-links a:hover {
            background: rgba(255,255,255,0.2);
            transform: translateY(-2px);
        }
        
        .content {
            padding: 30px;
        }
        
        .stats-overview {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(200px, 1fr));
            gap: 20px;
            margin-bottom: 30px;
        }
        
        .stat-card {
            background: linear-gradient(45deg, #667eea, #764ba2);
            color: white;
            padding: 20px;
            border-radius: 10px;
            text-align: center;
        }
        
        .stat-number {
            font-size: 2em;
            font-weight: bold;
            margin-bottom: 5px;
        }
        
        .filters {
            background: #f8f9fa;
            padding: 20px;
            border-radius: 10px;
            margin-bottom: 30px;
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(200px, 1fr));
            gap: 20px;
            align-items: end;
        }
        
        .filter-group {
            display: flex;
            flex-direction: column;
        }
        
        .filter-group label {
            font-weight: bold;
            margin-bottom: 5px;
            color: #333;
        }
        
        .filter-group select {
            padding: 10px;
            border: 2px solid #ddd;
            border-radius: 8px;
            font-size: 14px;
            transition: border-color 0.3s;
        }
        
        .filter-group select:focus {
            outline: none;
            border-color: #FF416C;
        }
        
        .events-table {
            width: 100%;
            border-collapse: collapse;
            background: white;
            border-radius: 10px;
            overflow: hidden;
            box-shadow: 0 4px 6px rgba(0,0,0,0.1);
            margin-bottom: 30px;
        }
        
        .events-table th,
        .events-table td {
            padding: 12px;
            text-align: left;
            border-bottom: 1px solid #eee;
        }
        
        .events-table th {
            background: linear-gradient(45deg, #667eea, #764ba2);
            color: white;
            font-weight: bold;
            position: sticky;
            top: 0;
            z-index: 10;
        }
        
        .events-table tr:hover {
            background: #f8f9fa;
        }
        
        .event-row {
            cursor: pointer;
        }
        
        .status-badge {
            padding: 4px 8px;
            border-radius: 12px;
            font-size: 0.8em;
            font-weight: bold;
            text-align: center;
            display: inline-block;
            min-width: 80px;
        }
        
        .status-upcoming { background: #ffc107; color: #000; }
        .status-live { background: #dc3545; color: #fff; animation: pulse 2s infinite; }
        .status-finished { background: #28a745; color: #fff; }
        .status-cancelled { background: #6c757d; color: #fff; }
        
        @keyframes pulse {
            0% { opacity: 1; }
            50% { opacity: 0.5; }
            100% { opacity: 1; }
        }
        
        .result-display {
            font-weight: bold;
            padding: 5px 10px;
            border-radius: 8px;
            background: #e9ecef;
        }
        
        .additional-events {
            font-size: 0.8em;
            color: #666;
            margin-top: 5px;
        }
        
        .bets-summary {
            text-align: center;
        }
        
        .bet-stat {
            display: inline-block;
            margin: 0 5px;
            padding: 2px 6px;
            border-radius: 4px;
            font-size: 0.8em;
        }
        
        .bet-won { background: #d4edda; color: #155724; }
        .bet-lost { background: #f8d7da; color: #721c24; }
        .bet-pending { background: #fff3cd; color: #856404; }
        
        .event-details {
            background: white;
            border-radius: 10px;
            padding: 25px;
            margin-bottom: 20px;
            box-shadow: 0 4px 6px rgba(0,0,0,0.1);
        }
        
        .back-button {
            display: inline-block;
            padding: 10px 20px;
            background: #FF416C;
            color: white;
            text-decoration: none;
            border-radius: 8px;
            font-weight: bold;
            margin-bottom: 20px;
            transition: background 0.3s;
        }
        
        .back-button:hover {
            background: #e8395a;
        }
        
        .bets-table {
            width: 100%;
            border-collapse: collapse;
            background: white;
            border-radius: 8px;
            overflow: hidden;
            margin-top: 20px;
        }
        
        .bets-table th,
        .bets-table td {
            padding: 10px;
            text-align: left;
            border-bottom: 1px solid #eee;
        }
        
        .bets-table th {
            background: #f8f9fa;
            font-weight: bold;
        }
        
        .bet-type-icon {
            font-size: 1.2em;
            margin-right: 5px;
        }
        
        .no-data {
            text-align: center;
            padding: 50px;
            color: #666;
        }
        
        @media (max-width: 1024px) {
            .events-table {
                font-size: 0.9em;
            }
            
            .events-table th,
            .events-table td {
                padding: 8px;
            }
        }
        
        @media (max-width: 768px) {
            .filters {
                grid-template-columns: 1fr;
            }
            
            .stats-overview {
                grid-template-columns: repeat(2, 1fr);
            }
            
            .events-table {
                font-size: 0.8em;
            }
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="header">
            <h1>📊 Детальная информация о событиях и ставках</h1>
            <p>Полный отчет по всем играм, результатам и ставкам</p>
            
            <div class="nav-links">
                <a href="admin_panel.php">📊 Админ панель</a>
                <a href="event_add.php">➕ Добавить событие</a>
                <a href="teams_table_page.php">🏆 Классическая таблица</a>
            </div>
        </div>
        
        <div class="content">
            <?php if ($selected_event && $event_details): ?>
                <!-- Детали выбранного события -->
                <a href="?" class="back-button">🔙 Назад к списку событий</a>
                
                <div class="event-details">
                    <h2>🏟 Подробная информация о событии</h2>
                    
                    <div style="display: grid; grid-template-columns: repeat(auto-fit, minmax(300px, 1fr)); gap: 20px; margin: 20px 0;">
                        <div>
                            <h3>📋 Основная информация</h3>
                            <p><strong>Название:</strong> <?= htmlspecialchars($event_details['title']) ?></p>
                            <p><strong>Команды:</strong> <?= htmlspecialchars($event_details['team1']) ?> vs <?= htmlspecialchars($event_details['team2']) ?></p>
                            <p><strong>Дата:</strong> <?= date('d.m.Y H:i', strtotime($event_details['event_date'])) ?></p>
                            <p><strong>Лига:</strong> <?= htmlspecialchars($event_details['league'] ?: 'Без лиги') ?></p>
                            <p><strong>Статус:</strong> <span class="status-badge status-<?= $event_details['status'] ?>"><?= ucfirst($event_details['status']) ?></span></p>
                        </div>
                        
                        <div>
                            <h3>📊 Статистика ставок</h3>
                            <p><strong>Всего ставок:</strong> <?= $event_details['total_bets'] ?></p>
                            <p><strong>Уникальных игроков:</strong> <?= $event_details['unique_bettors'] ?></p>
                            <p><strong>Выигрышных ставок:</strong> <span class="bet-won"><?= $event_details['winning_bets'] ?></span></p>
                            <p><strong>Проигрышных ставок:</strong> <span class="bet-lost"><?= $event_details['losing_bets'] ?></span></p>
                            <p><strong>Ожидающих:</strong> <span class="bet-pending"><?= $event_details['pending_bets'] ?></span></p>
                        </div>
                        
                        <?php if ($event_details['status'] === 'finished' && $event_details['result']): ?>
                            <?php $result = json_decode($event_details['result'], true); ?>
                            <div>
                                <h3>🏆 Результаты матча</h3>
                                <p><strong>Счет:</strong> <?= htmlspecialchars($result['score'] ?? 'Н/Д') ?></p>
                                <p><strong>Победитель:</strong> 
                                    <?php
                                    switch ($result['winner'] ?? '') {
                                        case 'team1': echo htmlspecialchars($event_details['team1']); break;
                                        case 'team2': echo htmlspecialchars($event_details['team2']); break;
                                        case 'draw': echo 'Ничья'; break;
                                        default: echo 'Н/Д';
                                    }
                                    ?>
                                </p>
                                <p><strong>Общий тотал:</strong> <?= $result['total_goals'] ?? 'Н/Д' ?></p>
                                
                                <?php if (isset($result['first_goal'])): ?>
                                    <p><strong>Первый гол:</strong> 
                                        <?= $result['first_goal'] === 'team1' ? htmlspecialchars($event_details['team1']) : htmlspecialchars($event_details['team2']) ?>
                                    </p>
                                <?php endif; ?>
                                
                                <div style="margin-top: 10px;">
                                    <?php if ($result['red_card'] ?? false): ?>
                                        <span class="bet-stat" style="background: #f8d7da;">🟥 Было удаление</span>
                                    <?php endif; ?>
                                    <?php if ($result['penalty'] ?? false): ?>
                                        <span class="bet-stat" style="background: #fff3cd;">🎯 Был пенальти</span>
                                    <?php endif; ?>
                                    <?php if ($result['own_goal'] ?? false): ?>
                                        <span class="bet-stat" style="background: #e2e3e5;">🤦 Был автогол</span>
                                    <?php endif; ?>
                                    <?php if (isset($result['corners_winner'])): ?>
                                        <span class="bet-stat" style="background: #d1ecf1;">📐 Угловые: 
                                            <?php
                                            switch ($result['corners_winner']) {
                                                case 'team1': echo htmlspecialchars($event_details['team1']); break;
                                                case 'team2': echo htmlspecialchars($event_details['team2']); break;
                                                case 'draw': echo 'поровну'; break;
                                            }
                                            ?>
                                        </span>
                                    <?php endif; ?>
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                    
                    <!-- Таблица ставок -->
                    <?php if (!empty($event_bets)): ?>
                        <h3>🎯 Все ставки на событие</h3>
                        <div style="overflow-x: auto;">
                            <table class="bets-table">
                                <thead>
                                    <tr>
                                        <th>Игрок</th>
                                        <th>Тип ставки</th>
                                        <th>Прогноз</th>
                                        <th>Потенциал</th>
                                        <th>Результат</th>
                                        <th>Статус</th>
                                        <th>Дата ставки</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($event_bets as $bet): ?>
                                        <tr>
                                            <td>
                                                <strong><?= htmlspecialchars($bet['first_name'] ?: 'Анонимный') ?></strong>
                                                <?php if ($bet['username']): ?>
                                                    <br><small>@<?= htmlspecialchars($bet['username']) ?></small>
                                                <?php endif; ?>
                                            </td>
                                            <td>
                                                <?php
                                                $bet_type_icons = [
                                                    'winner' => '🏆',
                                                    'exact_score' => '⚽',
                                                    'first_goal' => '🥅',
                                                    'total_goals' => '📊',
                                                    'red_card' => '🟥',
                                                    'penalty' => '🎯',
                                                    'own_goal' => '🤦',
                                                    'corners_winner' => '📐'
                                                ];
                                                $icon = $bet_type_icons[$bet['bet_type']] ?? '🎲';
                                                echo "<span class='bet-type-icon'>{$icon}</span>";
                                                
                                                $bet_type_names = [
                                                    'winner' => 'Победитель',
                                                    'exact_score' => 'Точный счет',
                                                    'first_goal' => 'Первый гол',
                                                    'total_goals' => 'Тотал голов',
                                                    'red_card' => 'Удаление',
                                                    'penalty' => 'Пенальти',
                                                    'own_goal' => 'Автогол',
                                                    'corners_winner' => 'Угловые'
                                                ];
                                                echo $bet_type_names[$bet['bet_type']] ?? $bet['bet_type'];
                                                ?>
                                            </td>
                                            <td>
                                                <strong><?= htmlspecialchars(formatBetDisplay($bet['bet_type'], $bet['bet_answer'], $event_details['team1'], $event_details['team2'])) ?></strong>
                                            </td>
                                            <td>+<?= $bet['potential_win'] ?> баллов</td>
                                            <td>
                                                <?php if ($bet['status'] === 'won'): ?>
                                                    <span class="bet-won">+<?= $bet['points_earned'] ?> баллов</span>
                                                <?php elseif ($bet['status'] === 'lost'): ?>
                                                    <span class="bet-lost">-2 балла</span>
                                                <?php else: ?>
                                                    <span class="bet-pending">Ожидание</span>
                                                <?php endif; ?>
                                            </td>
                                            <td>
                                                <?php
                                                $status_text = [
                                                    'pending' => '⏳ Ожидает',
                                                    'won' => '✅ Выиграла',
                                                    'lost' => '❌ Проиграла',
                                                    'cancelled' => '🚫 Отменена'
                                                ];
                                                echo $status_text[$bet['status']] ?? $bet['status'];
                                                ?>
                                            </td>
                                            <td><?= date('d.m.Y H:i', strtotime($bet['created_at'])) ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                        
                        <!-- Сводка по ставкам -->
                        <div style="margin-top: 20px; padding: 15px; background: #f8f9fa; border-radius: 8px;">
                            <h4>📈 Сводка результатов:</h4>
                            <div style="display: grid; grid-template-columns: repeat(auto-fit, minmax(150px, 1fr)); gap: 15px; margin-top: 10px;">
                                <div style="text-align: center;">
                                    <div style="font-size: 1.5em; font-weight: bold; color: #28a745;"><?= $event_details['winning_bets'] ?></div>
                                    <div>Выигрышных ставок</div>
                                </div>
                                <div style="text-align: center;">
                                    <div style="font-size: 1.5em; font-weight: bold; color: #dc3545;"><?= $event_details['losing_bets'] ?></div>
                                    <div>Проигрышных ставок</div>
                                </div>
                                <div style="text-align: center;">
                                    <div style="font-size: 1.5em; font-weight: bold; color: #ffc107;"><?= $event_details['pending_bets'] ?></div>
                                    <div>Ожидающих</div>
                                </div>
                                <div style="text-align: center;">
                                    <div style="font-size: 1.5em; font-weight: bold; color: #667eea;">
                                        <?= $event_details['total_bets'] > 0 ? round(($event_details['winning_bets'] / $event_details['total_bets']) * 100, 1) : 0 ?>%
                                    </div>
                                    <div>Процент побед</div>
                                </div>
                            </div>
                        </div>
                    <?php else: ?>
                        <div class="no-data">
                            <p>На это событие еще нет ставок</p>
                        </div>
                    <?php endif; ?>
                </div>
                
            <?php else: ?>
                <!-- Общая статистика -->
                <div class="stats-overview">
                    <div class="stat-card">
                        <div class="stat-number"><?= $total_events ?></div>
                        <div>Всего событий</div>
                    </div>
                    <div class="stat-card">
                        <div class="stat-number"><?= $live_events ?></div>
                        <div>В эфире</div>
                    </div>
                    <div class="stat-card">
                        <div class="stat-number"><?= $upcoming_events ?></div>
                        <div>Предстоящих</div>
                    </div>
                    <div class="stat-card">
                        <div class="stat-number"><?= $finished_events ?></div>
                        <div>Завершенных</div>
                    </div>
                    <div class="stat-card">
                        <div class="stat-number"><?= $total_bets ?></div>
                        <div>Всего ставок</div>
                    </div>
                </div>
                
                <!-- Фильтры -->
                <div class="filters">
                    <div class="filter-group">
                        <label for="status">📊 Статус событий:</label>
                        <select id="status" onchange="applyFilters()">
                            <option value="all" <?= $status_filter === 'all' ? 'selected' : '' ?>>Все события</option>
                            <option value="live" <?= $status_filter === 'live' ? 'selected' : '' ?>>🔴 В эфире</option>
                            <option value="upcoming" <?= $status_filter === 'upcoming' ? 'selected' : '' ?>>⏳ Предстоящие</option>
                            <option value="finished" <?= $status_filter === 'finished' ? 'selected' : '' ?>>✅ Завершенные</option>
                            <option value="cancelled" <?= $status_filter === 'cancelled' ? 'selected' : '' ?>>🚫 Отмененные</option>
                        </select>
                    </div>
                    
                    <div class="filter-group">
                        <label for="league">🏆 Лига/турнир:</label>
                        <select id="league" onchange="applyFilters()">
                            <option value="all" <?= $league_filter === 'all' ? 'selected' : '' ?>>Все лиги</option>
                            <?php foreach ($leagues as $league): ?>
                                <option value="<?= htmlspecialchars($league['league']) ?>" 
                                        <?= $league_filter === $league['league'] ? 'selected' : '' ?>>
                                    <?= htmlspecialchars($league['league']) ?> (<?= $league['events_count'] ?>)
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                </div>
                
                <?php if (empty($events)): ?>
                    <div class="no-data">
                        <h3>🤷‍♂️ Нет событий для отображения</h3>
                        <p>Попробуйте изменить фильтры или добавить новые события</p>
                        <br>
                        <a href="event_add.php" class="back-button">➕ Добавить событие</a>
                    </div>
                <?php else: ?>
                    <!-- Таблица событий -->
                    <div style="overflow-x: auto;">
                        <table class="events-table">
                            <thead>
                                <tr>
                                    <th>ID</th>
                                    <th>Статус</th>
                                    <th>Дата</th>
                                    <th>Событие</th>
                                    <th>Лига</th>
                                    <th>Результат</th>
                                    <th>Доп. события</th>
                                    <th>Ставки</th>
                                    <th>Игроки</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($events as $event): ?>
                                    <tr class="event-row" onclick="showEventDetails(<?= $event['event_id'] ?>)">
                                        <td><strong><?= $event['event_id'] ?></strong></td>
                                        <td>
                                            <span class="status-badge status-<?= $event['status'] ?>">
                                                <?php
                                                $status_names = [
                                                    'upcoming' => '⏳ Предстоящее',
                                                    'live' => '🔴 В эфире',
                                                    'finished' => '✅ Завершено',
                                                    'cancelled' => '🚫 Отменено'
                                                ];
                                                echo $status_names[$event['status']] ?? $event['status'];
                                                ?>
                                            </span>
                                        </td>
                                        <td>
                                            <strong><?= date('d.m.Y', strtotime($event['event_date'])) ?></strong><br>
                                            <small><?= date('H:i', strtotime($event['event_date'])) ?></small>
                                        </td>
                                        <td>
                                            <strong><?= htmlspecialchars($event['title']) ?></strong><br>
                                            <span style="color: #666;">
                                                <?= htmlspecialchars($event['team1']) ?> vs <?= htmlspecialchars($event['team2']) ?>
                                            </span>
                                        </td>
                                        <td><?= htmlspecialchars($event['league'] ?: 'Без лиги') ?></td>
                                        <td>
                                            <?php if ($event['status'] === 'finished' && $event['result']): ?>
                                                <?php $result = json_decode($event['result'], true); ?>
                                                <div class="result-display">
                                                    <strong><?= htmlspecialchars($result['score'] ?? 'Н/Д') ?></strong><br>
                                                    <small>
                                                        Тотал: <?= $result['total_goals'] ?? 'Н/Д' ?><br>
                                                        <?php
                                                        switch ($result['winner'] ?? '') {
                                                            case 'team1': echo "Победа: " . htmlspecialchars($event['team1']); break;
                                                            case 'team2': echo "Победа: " . htmlspecialchars($event['team2']); break;
                                                            case 'draw': echo 'Ничья'; break;
                                                            default: echo 'Н/Д';
                                                        }
                                                        ?>
                                                    </small>
                                                </div>
                                            <?php else: ?>
                                                <span style="color: #666;">-</span>
                                            <?php endif; ?>
                                        </td>
                                        <td>
                                            <?php if ($event['status'] === 'finished' && $event['result']): ?>
                                                <?php $result = json_decode($event['result'], true); ?>
                                                <div class="additional-events">
                                                    <?php if ($result['first_goal'] ?? false): ?>
                                                        🥅 Первый: <?= $result['first_goal'] === 'team1' ? htmlspecialchars($event['team1']) : htmlspecialchars($event['team2']) ?><br>
                                                    <?php endif; ?>
                                                    <?php if ($result['red_card'] ?? false): ?>
                                                        🟥 Удаление<br>
                                                    <?php endif; ?>
                                                    <?php if ($result['penalty'] ?? false): ?>
                                                        🎯 Пенальти<br>
                                                    <?php endif; ?>
                                                    <?php if ($result['own_goal'] ?? false): ?>
                                                        🤦 Автогол<br>
                                                    <?php endif; ?>
                                                    <?php if ($result['corners_winner'] ?? false): ?>
                                                        📐 Угловые: <?php
                                                        switch ($result['corners_winner']) {
                                                            case 'team1': echo htmlspecialchars($event['team1']); break;
                                                            case 'team2': echo htmlspecialchars($event['team2']); break;
                                                            case 'draw': echo 'поровну'; break;
                                                        }
                                                        ?><br>
                                                    <?php endif; ?>
                                                </div>
                                            <?php else: ?>
                                                <span style="color: #666;">-</span>
                                            <?php endif; ?>
                                        </td>
                                        <td class="bets-summary">
                                            <strong><?= $event['total_bets'] ?></strong> всего<br>
                                            <?php if ($event['total_bets'] > 0): ?>
                                                <span class="bet-stat bet-won"><?= $event['winning_bets'] ?> ✅</span>
                                                <span class="bet-stat bet-lost"><?= $event['losing_bets'] ?> ❌</span>
                                                <?php if ($event['pending_bets'] > 0): ?>
                                                    <span class="bet-stat bet-pending"><?= $event['pending_bets'] ?> ⏳</span>
                                                <?php endif; ?>
                                            <?php endif; ?>
                                        </td>
                                        <td><strong><?= $event['unique_bettors'] ?></strong> игроков</td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>
            <?php endif; ?>
        </div>
    </div>

    <script>
        function applyFilters() {
            const status = document.getElementById('status').value;
            const league = document.getElementById('league').value;
            
            const params = new URLSearchParams(window.location.search);
            params.set('status', status);
            params.set('league', league);
            
            window.location.href = '?' + params.toString();
        }
        
        function showEventDetails(eventId) {
            const params = new URLSearchParams(window.location.search);
            params.set('event_id', eventId);
            window.location.href = '?' + params.toString();
        }
    </script>
</body>
</html>